@@ -48,18 +48,10 @@ static const char *__ecc_status_help =
 "Returns the current hardware ECC setting "
 "for the targeted GPU.";
 
-static const char *__sbit_error_help =
-"Returns the number of single-bit ECC errors detected by "
-"the targeted GPU since the last POST.";
-
 static const char *__dbit_error_help =
 "Returns the number of double-bit ECC errors detected by "
 "the targeted GPU since the last POST.";
 
-static const char *__aggregate_sbit_error_help =
-"Returns the number of single-bit ECC errors detected by the "
-"targeted GPU since the last counter reset.";
-
 static const char *__aggregate_dbit_error_help =
 "Returns the number of double-bit ECC errors detected by the "
 "targeted GPU since the last counter reset.";
@@ -172,16 +164,6 @@ static gboolean update_ecc_info(gpointer user_data)
     
     /* Query ECC Errors */
 
-    if ( ctk_ecc->sbit_error ) {
-        ret = NvCtrlGetAttribute64(ctk_ecc->handle,
-                                   NV_CTRL_GPU_ECC_SINGLE_BIT_ERRORS,
-                                   &val);
-        if ( ret != NvCtrlSuccess ) {
-            val = 0;
-        }
-        set_label_value(ctk_ecc->sbit_error, val);
-    }
-
     if ( ctk_ecc->dbit_error ) {
         ret = NvCtrlGetAttribute64(ctk_ecc->handle,
                                    NV_CTRL_GPU_ECC_DOUBLE_BIT_ERRORS,
@@ -192,16 +174,6 @@ static gboolean update_ecc_info(gpointer user_data)
         set_label_value(ctk_ecc->dbit_error, val);
     }
 
-    if ( ctk_ecc->aggregate_sbit_error ) {
-        ret = NvCtrlGetAttribute64(ctk_ecc->handle,
-                                   NV_CTRL_GPU_ECC_AGGREGATE_SINGLE_BIT_ERRORS,
-                                   &val);
-        if ( ret != NvCtrlSuccess ) {
-            val = 0;
-        }
-        set_label_value(ctk_ecc->aggregate_sbit_error, val);
-    }
-
     if ( ctk_ecc->aggregate_dbit_error ) {
         ret = NvCtrlGetAttribute64(ctk_ecc->handle,
                                    NV_CTRL_GPU_ECC_AGGREGATE_DOUBLE_BIT_ERRORS,
@@ -335,12 +307,12 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
     CtkEcc *ctk_ecc;
     GtkWidget *hbox, *hbox2, *vbox, *hsep, *hseparator, *table;
     GtkWidget *banner, *label, *eventbox;
-    int64_t sbit_error, dbit_error, aggregate_sbit_error;
+    int64_t dbit_error;
     int64_t aggregate_dbit_error;
     gint ecc_config_supported;
     gint val, row = 0;
-    gboolean sbit_error_available, dbit_error_available;
-    gboolean aggregate_sbit_error_available, aggregate_dbit_error_available;
+    gboolean dbit_error_available;
+    gboolean aggregate_dbit_error_available;
     gboolean ecc_enabled;
     ReturnStatus ret;
     gchar *ecc_enabled_string;
@@ -368,13 +340,11 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
     ctk_ecc->handle = handle;
     ctk_ecc->ctk_config = ctk_config;
 
-    sbit_error_available = TRUE;
     dbit_error_available = TRUE;
-    aggregate_sbit_error_available = TRUE;
     aggregate_dbit_error_available = TRUE;
     
-    sbit_error = dbit_error = 0;
-    aggregate_sbit_error = aggregate_dbit_error = 0;
+    dbit_error = 0;
+    aggregate_dbit_error = 0;
 
     /* Query ECC Status */
 
@@ -391,23 +361,11 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
 
     /* Query ECC errors */
     
-    ret = NvCtrlGetAttribute64(handle, NV_CTRL_GPU_ECC_SINGLE_BIT_ERRORS,
-                             &sbit_error);
-    if ( ret != NvCtrlSuccess ) {
-        sbit_error_available = FALSE;
-    }
-    
     ret = NvCtrlGetAttribute64(handle, NV_CTRL_GPU_ECC_DOUBLE_BIT_ERRORS,
                              &dbit_error);
     if ( ret != NvCtrlSuccess ) {
         dbit_error_available = FALSE;
     }
-    ret = NvCtrlGetAttribute64(handle,
-                             NV_CTRL_GPU_ECC_AGGREGATE_SINGLE_BIT_ERRORS,
-                             &aggregate_sbit_error);
-    if ( ret != NvCtrlSuccess ) {
-        aggregate_sbit_error_available = FALSE;
-    }
     ret = NvCtrlGetAttribute64(handle,
                              NV_CTRL_GPU_ECC_AGGREGATE_DOUBLE_BIT_ERRORS,
                              &aggregate_dbit_error);
@@ -474,12 +432,7 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
     
     /* Add ECC Errors */
 
-    if ( sbit_error_available && dbit_error_available ) {
-        ctk_ecc->sbit_error =
-            add_table_int_row(ctk_config, table, __sbit_error_help,
-                              "Single-bit ECC Errors:", sbit_error,
-                              row, ecc_enabled);
-        row += 1;
+    if ( dbit_error_available ) {
         ctk_ecc->dbit_error =
             add_table_int_row(ctk_config, table, __dbit_error_help,
                               "Double-bit ECC Errors:", dbit_error,
@@ -487,13 +440,7 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
         row += 3; // add vertical padding between rows
     }
     
-    if ( aggregate_sbit_error_available && aggregate_dbit_error_available ) {
-        ctk_ecc->aggregate_sbit_error =
-            add_table_int_row(ctk_config, table, __aggregate_sbit_error_help,
-                              "Aggregate Single-bit ECC Errors:",
-                              aggregate_sbit_error,
-                              row, ecc_enabled);
-        row += 1;
+    if ( aggregate_dbit_error_available ) {
         ctk_ecc->aggregate_dbit_error =
             add_table_int_row(ctk_config, table, __aggregate_dbit_error_help,
                               "Aggregate Double-bit ECC Errors:",
@@ -530,7 +477,7 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
     
     /* Add buttons */
 
-    if ( sbit_error_available && dbit_error_available ) {
+    if ( dbit_error_available ) {
         ctk_ecc->clear_button = gtk_button_new_with_label("Clear ECC Errors");
         gtk_box_pack_end(GTK_BOX(hbox), ctk_ecc->clear_button, FALSE, FALSE, 0);
         ctk_config_set_tooltip(ctk_config, ctk_ecc->clear_button,
@@ -541,7 +488,7 @@ GtkWidget* ctk_ecc_new(NvCtrlAttributeHandle *handle,
                          (gpointer) ctk_ecc);
     }
 
-    if ( aggregate_sbit_error_available && aggregate_dbit_error_available ) {
+    if ( aggregate_dbit_error_available ) {
         ctk_ecc->clear_aggregate_button =
             gtk_button_new_with_label("Clear Aggregate ECC Errors");
         gtk_box_pack_end(GTK_BOX(hbox), ctk_ecc->clear_aggregate_button,
@@ -601,15 +548,9 @@ GtkTextBuffer *ctk_ecc_create_help(GtkTextTagTable *table,
     ctk_help_heading(b, &i, "ECC");
     ctk_help_para(b, &i, __ecc_status_help);
 
-    ctk_help_heading(b, &i, "Single-bit ECC Errors");
-    ctk_help_para(b, &i, __sbit_error_help);
-
     ctk_help_heading(b, &i, "Double-bit ECC Errors");
     ctk_help_para(b, &i, __dbit_error_help);
 
-    ctk_help_heading(b, &i, "Aggregate Single-bit ECC Errors");
-    ctk_help_para(b, &i, __aggregate_sbit_error_help);
-
     ctk_help_heading(b, &i, "Aggregate Double-bit ECC Errors");
     ctk_help_para(b, &i, __aggregate_dbit_error_help);
 
