@@ -125,38 +125,62 @@ void get_bus_related_info(NvCtrlAttributeHandle *handle,
                           gchar **bus,
                           gchar **pci_bus_id)
 {
-    int tmp, ret;
+    int tmp, ret, bus_type;
     int pci_domain, pci_bus, pci_device, pci_func;
-    gchar *bus_type, *bus_rate, *bus_id;
+    gchar *bus_type_str, *bus_rate, *pcie_gen, *bus_id;
     gchar *__pci_bus_id_unknown = "?@?:?:?";
     
     /* NV_CTRL_BUS_TYPE */
 
-    ret = NvCtrlGetAttribute(handle, NV_CTRL_BUS_TYPE, &tmp);
-    bus_type = NULL;
+    bus_type = 0xffffffff;
+    bus_type_str = "Unknown";
+    ret = NvCtrlGetAttribute(handle, NV_CTRL_BUS_TYPE, &bus_type);
     if (ret == NvCtrlSuccess) {
-        if      (tmp == NV_CTRL_BUS_TYPE_AGP) bus_type = "AGP";
-        else if (tmp == NV_CTRL_BUS_TYPE_PCI) bus_type = "PCI";
-        else if (tmp == NV_CTRL_BUS_TYPE_PCI_EXPRESS) bus_type = "PCI Express";
-        else if (tmp == NV_CTRL_BUS_TYPE_INTEGRATED) bus_type = "Integrated";
+        if      (bus_type == NV_CTRL_BUS_TYPE_AGP)
+            bus_type_str = "AGP";
+        else if (bus_type == NV_CTRL_BUS_TYPE_PCI)
+            bus_type_str = "PCI";
+        else if (bus_type == NV_CTRL_BUS_TYPE_PCI_EXPRESS)
+            bus_type_str = "PCI Express";
+        else if (bus_type == NV_CTRL_BUS_TYPE_INTEGRATED)
+            bus_type_str = "Integrated";
     }
 
     /* NV_CTRL_BUS_RATE */
 
     bus_rate = NULL;
-    if (tmp == NV_CTRL_BUS_TYPE_AGP ||
-        tmp == NV_CTRL_BUS_TYPE_PCI_EXPRESS) {
+    if (bus_type == NV_CTRL_BUS_TYPE_AGP ||
+        bus_type == NV_CTRL_BUS_TYPE_PCI_EXPRESS) {
         ret = NvCtrlGetAttribute(handle, NV_CTRL_BUS_RATE, &tmp);
         if (ret == NvCtrlSuccess) {
-            bus_rate = g_strdup_printf("%dX", tmp);
+            if (bus_type == NV_CTRL_BUS_TYPE_PCI_EXPRESS) {
+                bus_rate = g_strdup_printf("x%u", tmp);
+            } else {
+                bus_rate = g_strdup_printf("%uX", tmp);
+            }
         }
     }
 
-    if (bus_rate) {
-        *bus = g_strdup_printf("%s %s", bus_type, bus_rate);
+    /* NV_CTRL_GPU_PCIE_GENERATION */
+
+    pcie_gen = NULL;
+    if (bus_type == NV_CTRL_BUS_TYPE_PCI_EXPRESS) {
+        ret = NvCtrlGetAttribute(handle, NV_CTRL_GPU_PCIE_GENERATION, &tmp);
+        if (ret == NvCtrlSuccess)
+            pcie_gen = g_strdup_printf("Gen%u", tmp);
+    }
+
+    /* concatenate all the available bus related information */
+
+    if (bus_rate || pcie_gen) {
+        *bus = g_strdup_printf("%s %s%s%s", bus_type_str,
+                               bus_rate ? bus_rate : "",
+                               bus_rate ? " " : "",
+                               pcie_gen ? pcie_gen : "");
         g_free(bus_rate);
+        g_free(pcie_gen);
     } else {
-        *bus = g_strdup(bus_type);
+        *bus = g_strdup(bus_type_str);
     }
 
     /* NV_CTRL_PCI_DOMAIN & NV_CTRL_PCI_BUS &
@@ -221,12 +245,16 @@ GtkWidget* ctk_gpu_new(
     gchar *screens;
     gchar *displays;
     gchar *tmp_str;
+    gchar *gpu_cores;
+    gchar *memory_interface;
 
     unsigned int display_devices;
     int xinerama_enabled;
     int *pData;
     int len;
     int i;
+    int row = 0;
+    int total_rows = 19;
 
 
     /*
@@ -282,7 +310,25 @@ GtkWidget* ctk_gpu_new(
     } else {
         video_ram = g_strdup_printf("%d MB", tmp >> 10);
     }
+    
+    /* NV_CTRL_GPU_CORES */
 
+    ret = NvCtrlGetAttribute(handle, NV_CTRL_GPU_CORES, &tmp);
+    if (ret != NvCtrlSuccess) {
+        gpu_cores = NULL;
+    } else {
+        gpu_cores = g_strdup_printf("%d", tmp);
+    }
+
+    /* NV_CTRL_GPU_MEMORY_BUS_WIDTH  */
+
+    ret = NvCtrlGetAttribute(handle, NV_CTRL_GPU_MEMORY_BUS_WIDTH, &tmp);
+    if (ret != NvCtrlSuccess) {
+        memory_interface = NULL;
+    } else {
+        memory_interface = g_strdup_printf("%d-bit", tmp);
+    }
+    
     /* NV_CTRL_IRQ */
     
     ret = NvCtrlGetAttribute(handle, NV_CTRL_IRQ, &tmp);
@@ -363,6 +409,8 @@ GtkWidget* ctk_gpu_new(
     /* cache the attribute handle */
 
     ctk_gpu->handle = handle;
+    ctk_gpu->gpu_cores = (gpu_cores != NULL) ? 1 : 0;
+    ctk_gpu->memory_interface = (memory_interface != NULL) ? 1 : 0;
 
     /* set container properties of the object */
 
@@ -393,44 +441,59 @@ GtkWidget* ctk_gpu_new(
     hseparator = gtk_hseparator_new();
     gtk_box_pack_start(GTK_BOX(hbox), hseparator, TRUE, TRUE, 5);
 
-    table = gtk_table_new(19, 2, FALSE);
+    table = gtk_table_new(total_rows, 2, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
     gtk_table_set_row_spacings(GTK_TABLE(table), 3);
     gtk_table_set_col_spacings(GTK_TABLE(table), 15);
     gtk_container_set_border_width(GTK_CONTAINER(table), 5);
 
-    add_table_row(table, 0,
+    add_table_row(table, row++,
                   0, 0.5, "Graphics Processor:",
                   0, 0.5, product_name);
-    add_table_row(table, 1,
+    if ( ctk_gpu->gpu_cores ) {
+        gtk_table_resize(GTK_TABLE(table), ++total_rows, 2);
+        add_table_row(table, row++,
+                      0, 0.5, "CUDA Cores:",
+                      0, 0.5, gpu_cores);
+    }
+    add_table_row(table, row++,
                   0, 0.5, "VBIOS Version:",
                   0, 0.5, vbios_version);
-    add_table_row(table, 2,
+    add_table_row(table, row++,
                   0, 0.5, "Memory:",
                   0, 0.5, video_ram);
+    if ( ctk_gpu->memory_interface ) {
+        gtk_table_resize(GTK_TABLE(table), ++total_rows, 2);
+        add_table_row(table, row++,
+                      0, 0.5, "Memory Interface:",
+                      0, 0.5, memory_interface);
+    }
     /* spacing */
-    add_table_row(table, 6,
+    row += 3;
+    add_table_row(table, row++,
                   0, 0.5, "Bus Type:",
                   0, 0.5, bus);
-    add_table_row(table, 7,
+    add_table_row(table, row++,
                   0, 0.5, "Bus ID:",
                   0, 0.5, pci_bus_id);
-    add_table_row(table, 8,
+    add_table_row(table, row++,
                   0, 0.5, "PCI Device ID:",
                   0, 0.5, pci_device_id);
-    add_table_row(table, 9,
+    add_table_row(table, row++,
                   0, 0.5, "PCI Vendor ID:",
                   0, 0.5, pci_vendor_id);
-    add_table_row(table, 10,
+    add_table_row(table, row++,
                   0, 0.5, "IRQ:",
                   0, 0.5, irq);
     /* spacing */
-    add_table_row(table, 14,
+    row += 3;
+    add_table_row(table, row++,
                   0, 0, "X Screens:",
                   0, 0, screens);
     /* spacing */
+    row += 3;
     ctk_gpu->displays =
-        add_table_row(table, 18,
+        add_table_row(table, row,
                       0, 0, "Display Devices:",
                       0, 0, displays);
 
@@ -438,6 +501,8 @@ GtkWidget* ctk_gpu_new(
     XFree(vbios_version);
     g_free(video_ram);
     g_free(bus);
+    g_free(gpu_cores);
+    g_free(memory_interface);
     g_free(pci_bus_id);
     g_free(irq);
     g_free(screens);
@@ -456,7 +521,8 @@ GtkWidget* ctk_gpu_new(
 }
 
     
-GtkTextBuffer *ctk_gpu_create_help(GtkTextTagTable *table)
+GtkTextBuffer *ctk_gpu_create_help(GtkTextTagTable *table, 
+                                   CtkGpu *ctk_gpu)
 {
     GtkTextIter i;
     GtkTextBuffer *b;
@@ -475,6 +541,12 @@ GtkTextBuffer *ctk_gpu_create_help(GtkTextTagTable *table)
     ctk_help_heading(b, &i, "Graphics Processor");
     ctk_help_para(b, &i, "This is the product name of the GPU.");
     
+    if (ctk_gpu->gpu_cores) {
+        ctk_help_heading(b, &i, "CUDA Cores");
+        ctk_help_para(b, &i, "This is the number of CUDA cores supported by "
+                      "the graphics pipeline.");
+    }
+    
     ctk_help_heading(b, &i, "VBIOS Version");
     ctk_help_para(b, &i, "This is the Video BIOS version.");
     
@@ -487,6 +559,12 @@ GtkTextBuffer *ctk_gpu_create_help(GtkTextTagTable *table)
                   "dedicated system memory set aside by the system "
                   "BIOS for use by the integrated GPU.");
 
+    if (ctk_gpu->memory_interface) {
+        ctk_help_heading(b, &i, "Memory Interface");
+        ctk_help_para(b, &i, "This is the bus bandwidth of the GPU's "
+                      "memory interface.");
+    }
+
     ctk_help_heading(b, &i, "Bus Type");
     ctk_help_para(b, &i, "This is the bus type which is "
                   "used to connect the NVIDIA GPU to the rest of "
@@ -495,8 +573,8 @@ GtkTextBuffer *ctk_gpu_create_help(GtkTextTagTable *table)
     
     ctk_help_heading(b, &i, "Bus ID");
     ctk_help_para(b, &i, "This is the GPU's PCI identification string, "
-                  "reported in the form 'bus:device:function'. It uniquely "
-                  "identifies the GPU's location in the host system. "
+                  "reported in the form 'bus:device:function'.  It uniquely "
+                  "identifies the GPU's location in the host system.  "
                   "This string can be used as-is with the 'BusID' X "
                   "configuration file option to unambiguously associate "
                   "Device sections with this GPU.");
